==> haskell-filestore-0.6.5.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-K7KZ9YPmz6LJ0C8CA1OZN1
key:                  filestore-0.6.5.1-K7KZ9YPmz6LJ0C8CA1OZN1
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  4daad8fbba37fddc980b3438479c6660
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-K7KZ9YPmz6LJ0C8CA1OZN1
depends:
    Diff-0.4.1-EPHFVS7K0Jk50U1vJ3ZOtn base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filestore-0.6.5.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-4Gzz8pyJey67WOjDAA9k46
key:                  filestore-0.6.5.1-4Gzz8pyJey67WOjDAA9k46
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  e738880c7c26dc0640bad24da88752bd
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-4Gzz8pyJey67WOjDAA9k46
depends:
    Diff-0.4.1-Ku34wyKp5JHHh0VBRQYd7N base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
